# The purpose of this script is to re-check the Raman FWHM to aragonite saturation state (omega) calibration presented in DeCarlo et al. (2017) manuscript under review in Biogeosciences Discussions
# Code created 24 July, 2017

# First check: use given measured JCP-1 FWHM and reported calibration equation
JCP_fwhm = 3.51 # measured Raman FWHM (1/cm); see page 8 of manuscript
JCP_omega_check1 = exp((3.51-2.09)/0.57) # using coefficients in Table 2 under "WITec measured" row
print(paste("JCP-1 Omega using given FWHM measurement and calibration: ", round(JCP_omega_check1, 2)))
# answer is 12.08

# Second check: use the presented abiogenic FWHM from the supplement table to make calibration to Omega and apply to JCP-1 measurement:
# experiment names: f02, f03, f06, g07, g13, h09
measured_FWHM = c(3.75, 4.05, 3.45, 3.91, 3.46, 3.52) # measured FWHM (Table S2)
measured_FWHM_error = c(0.02, 0.02, 0.01, 0.02, 0.01, 0.01) # FWHM uncertainty (Table S2)
omega = c(19, 30, 11, 24, 10, 14) # reported Omega (Table S1)
omega_error = c(3, 4, 1, 3, 3, 3) # Omega uncertainty (Table S1)
logOmega = log(omega) # transform Omega to logarithmic
model1 = lm(measured_FWHM ~ logOmega) # make calibration using same technique presented in manuscript:
JCP_omega_model1 = exp((JCP_fwhm - coef(model1)[1])/coef(model1)[2]) # apply equation to JCP-1 FWHM
print(paste("JCP-1 Omega refitting after abiogenic calibration: ", round(JCP_omega_model1, 2)))
# answer is 12.12

# Third check: same as second check above, but fit the model such that Omega is a function of FWHM:
model2 = lm(logOmega ~ measured_FWHM) # log(Omega) depends on FWHM (not physical interpretation, but good check for calibration purposes)
JCP_omega_model2 = exp(JCP_fwhm*coef(model2)[2] + coef(model2)[1]) # apply equation to JCP-1 FWHM
print(paste("JCP-1 Omega refitting abiogenic calibration with Omega as function of FWHM: ", round(JCP_omega_model2, 2)))
# answer is 12.23

# These different methods give JCP-1 Omega within a range of 12.08 to 12.23. These values differ slightly from the value presented in the manuscript (12.3 +/- 0.3) because there we calculated Omega on the 440 replicate JCP-1 measurements and then took the average of the Omega values. This difference arises because the calibration is fit with the log of Omega. However, the differences in the calculations are quite small, probably negligible. In fact, the derived JCP-1 Omega is within error of that presented in the manuscript regardless of which approach is used.


# Re-plot calibration using FWHM vs Omega, and Omega vs. FWHM
mar.default = c(5.1, 4.1, 4.1, 2.1) # adjust figure margins slightly
par(mar = mar.default + c(0,0.65,0,0))
plot(omega, measured_FWHM, pch=21, bg="black", cex = 1.3, xlab=expression(Omega[Ar]), ylab = expression(paste(nu[1],' FWHM (cm'^-1*')')))
arrows(omega, measured_FWHM - measured_FWHM_error, omega, measured_FWHM + measured_FWHM_error, length=0.05, angle=90, code=3)
arrows(omega - omega_error, measured_FWHM, omega + omega_error, measured_FWHM, length=0.05, angle=90, code=3)
omegaVec = seq(min(omega),max(omega),0.01) # vector of Omega for plotting
fwhmVec = seq(min(measured_FWHM),max(measured_FWHM),0.01) # vector of FWHM for plotting
lines(exp((fwhmVec - coef(model1)[1])/coef(model1)[2]), fwhmVec, lwd=2, col="red")
lines(exp(fwhmVec*coef(model2)[2] + coef(model2)[1]), fwhmVec, lwd=2, col="blue")
legend("bottomright",c(expression(paste("FWHM as a function of ",Omega[Ar])), expression(paste(Omega[Ar]," as a function of FWHM"))), lty=c(1,1), lwd=c(2,2), col=c("red","blue"))